#!/usr/local/bin/perl

#------------------------------------------------------------------------------
# Text Counter日ごとカウント(SSI式)
# v0.5.1(2006-7-23)
# 
# atelier-blue 利都(rito)
# http://www.atelier-blue.com/
#------------------------------------------------------------------------------
$version = 'Text Counter(SSI) ver0.5.1(2006-7-23)';
# [説明]
# utf-8形式で出力されます。
# 二つのログファイルを利用してカスケード書き込みで動きます。
#
# [タグの記述例]
#
# <!--#exec cgi="./cgi-bin/text_counter/counter.cgi"-->
#
# [ディレクトリ構成例]
# public_html / index.shtml ← ここにタグ記述：カウンタ表示
#   |
#   +-- cgi-bin
#           |
#           +-- text_counter /  counter.cgi    [700]（注・パーミッション設定については「readme.txt」を参照）
#                   |           count_log1.log [600]
#                   |           count_log2.log [600]
#
# [チェックモード]
#「http://～～～/counter.cgi?check」と入力すると、チェックモードで動きます。


#回数が記録されたファイル(二つの名前がかぶらないようにお願いします)
$count_file1 = "./count_log1.log";
$count_file2 = "./count_log2.log";

#エラーの表示(0:しない,1する)
$error_print = 0;

#出力文字列。２つのシングルコーテーションの間に文字列を書く。次の文字は置き換えられる。
#(count)     :総計
#(today)     :今日のカウント
#(yesterday) :昨日のカウント
$out_string = '
<div class="counter"><p>
<span class="all"> (count) </span><br />
<span class="yesterday"> Yesterday: (yesterday) </span>
<span class="today">Today: (today) </span>
</p></div>';


#==============#
# 設定ここまで
#==============#


if ($ENV{'QUERY_STRING'} eq "check") { &check; }

# 日付を取得
$ENV{'TZ'} = "JST-9";
$mday = (localtime(time))[3];

#読み込み
open(IN1,"$count_file1") || &error("File open errer. $count_file1");
open(IN2,"$count_file2") || &error("File open errer. $count_file2");
$in_data1 = <IN1>;
$in_data2 = <IN2>;
close(IN1);
close(IN2);
($count1,$day1, $yesterday1, $today1) = split(/:/, $in_data1);
($count2,$day2, $yesterday2, $today2) = split(/:/, $in_data2);

#新しい方のデータを利用する。
if($count1 > $count2){
	$count = $count1;
	#日を進める
	if($mday != $day1){
		$yesterday = $today1;
	}else{
		$today =$today1;
		$yesterday = $yesterday1;
	}
	$count++;
	$today++;
	#書き込みファイルを設定
	$write_file = $count_file2;
}else{
	$count = $count2;
	if($mday != $day2){
		$yesterday = $today2;
	}else{
		$today =$today2;
		$yesterday = $yesterday2;
	}
	
	$count++;
	$today++;
	
	$write_file = $count_file1;
}
#書き込み
open(OUT,">$write_file") || &error("File open errer. $write_file");
print OUT "$count:$mday:$yesterday:$today";
close(OUT);


#出力
print "Content-type: text/plain\n\n";
$out_string =~ s/\(count\)/$count/;
$out_string =~ s/\(yesterday\)/$yesterday/;
$out_string =~ s/\(today\)/$today/;

print $out_string;

exit;

#----------------------------------------------------------------------#
#チェック
#	引数：なし
#	返り値：なし
#	呼び出し例：&error;
#----------------------------------------------------------------------#
sub check{
	&header("チェック:$version");
	print "<h1>$version</h1>";
	print '<h2>ログファイル</h2><ul>';
	foreach ($count_file1, $count_file2 ) {
		print '<li>';
		# 有無
		if (-e $_) {
			print "パス : $_ … OK<ul>";
			# パーミッション
			if (-r $_ && -w $_){
				print "<li>パーミッション：$_ … OK</li>";
			}else{
				print "<li>パーミッション：$_ … <strong> 【NG】 </strong> 書き込み、読み込みが出来るように設定してください。</li>";
			}
			print '</ul>';
		}else{
			print "パス : $_ … <strong> 【NG】 </strong> パスがおかしい、または存在しません。";
		}
		print '</li>';
	}
	print '</ul>';
	
	&footer;
	exit;
}

#----------------------------------------------------------------------#
#エラー処理
#	引数：エラーメッセージ
#	返り値：特になし
#	呼び出し例：&error("データ読み込みに失敗しました") ;
#		※メッセージを表示し、プログラムを終了する
#		※表示の為にヘッダーサブルーチン・フッターサブルーチンを利用
#----------------------------------------------------------------------#
sub error {
	if($error_print){
		&header;
		print "<br /><br /><br />$_[0]<br /><br /><br />";
		&footer;
	}
	exit;
}

#----------------------------------------------------------------------#
#HTMLフッター書き出し
#	引数：特になし
#	返り値：特になし
#	呼び出し例：&footer ;
#----------------------------------------------------------------------#
sub footer { 
	print "</body></html>\n";
}

#----------------------------------------------------------------------#
#HTMLヘッダー書き出し
#	引数：HTMLのタイトル,スタイルシートのパス
#	返り値：特になし
#	呼び出し例：&header('MyPage','./css.css') ;
#----------------------------------------------------------------------#
sub header { 
	my($html_title,$css_path) = @_ ;
	
	print "Content-Type: text/html; charset=utf-8\n\n" ;
	print "<?xml version=\"1.0\" encoding=\"utf-8\" ?>\n" ;
	print "<!DOCTYPE html PUBLIC \"-//W3C//DTD XHTML 1.1//EN\"\n" ;
	print "		\"http://www.w3.org/TR/xhtml11/DTD/xhtml11.dtd\">\n" ;
	print "<html xmlns=\"http://www.w3.org/1999/xhtml\" xml:lang=\"ja\">\n" ;
	print "<head>\n" ;
	print "<title>$html_title</title>\n" ;
	if($css_path ne ""){
		print "<link rel=\"stylesheet\" type=\"text/css\" href=\"$css_path\" />\n" ;
	}
	print "</head>\n" ;
	print "<body>\n" ;
}

__END__

